***********************************************************************
* File: DelayUs.asm
* Devices: TMS320F2808, TMS320F2806, TMS320F2801
* Author: Technical Training Organization (TTO), Texas Instruments
* History:
*   09/26/05 - original (based on DSP280x header files v1.20)
***********************************************************************

WDKEY	.set	0x7025

**********************************************************************
* Function: DelayUs()                                                *
* Description: Implements a time delay.                              *
* DSP: TMS320F2808, TMS320F2806, TMS320F2801                         *
* Last Modified: 05/25/05                                            *
* Include files: none                                                *
* Function Prototype: void DelayUs(unsigned int)                     *
* Useage: DelayUs(Usec);                                             *
* Input Parameters: unsigned int Usec = time delay in microseconds   *
* Return Value: none                                                 *
* Notes: The execution time of this routine is based upon a 100 MHz  *
*        CPUCLK.  It also assumes that the function executes out of  *
*        internal RAM.  If executing out of internal flash, the      *
*        execution speed will be slightly slower.  However, the      *
*        inner loop of this function is essentially invariant to the *
*        memory it is running in.  Therefore, even when running in   *
*        flash memory, the basic loop time will be only slightly     *
*        longer than 1 us.                                           *   
**********************************************************************
       .def _DelayUs
       .text

_DelayUs:

		MOVB AH, #0                   ;zero AH

DelayUs1:

; Service the watchdog in case it is active
		EALLOW
		MOVZ DP, #(WDKEY>>6)
		MOV @WDKEY, #0x0055
		MOV @WDKEY, #0x00AA
		EDIS

;Proceed with the inner loop
        RPT #88                       ;inner loop
     || NOP

        SUBB ACC,#1                   ;decrement outer loop counter
        BF DelayUs1, GT               ;branch for outer loop

        LRETR                         ;return

; end of function DelayUs() ******************************************


;end of file DelayUs.asm
       .end
